%global _vpath_builddir %{_vendor}-%{_target_os}-build

Summary: Set of libraries and drivers for fast packet processing
Name: dpdk
Version: 22.11.1
Release: 7%{?dist}
License: BSD and LGPLv2 and GPLv2
URL: http://dpdk.org
Source0: https://fast.dpdk.org/rel/dpdk-%{version}.tar.xz

Patch3000: CVE-2024-11614.patch

BuildRequires: meson gcc
BuildRequires: kernel-headers, libpcap-devel, doxygen, /usr/bin/sphinx-build, zlib-devel
BuildRequires: numactl-devel rdma-core-devel openssl-devel libbpf-devel
BuildRequires: libatomic libarchive-devel python3-pyelftools

ExclusiveArch: x86_64 aarch64 ppc64le loongarch64

%description
DPDK is the Data Plane Development Kit that consists of libraries to
accelerate packet processing workloads running on a wide variety of
CPU architectures.

%package devel
Summary: Data Plane Development Kit development files
Requires: %{name} = %{version}-%{release} python3
Requires: rdma-core-devel

%description devel
This package contains the headers and libraries needed for developing
applications with the %{name}.

%package tools
Summary: Tools for setting up Data Plane Development Kit environment
Requires: %{name} = %{version}-%{release}
Requires: kmod pciutils findutils iproute python3-pyelftools

%description tools
This package provides some tools which can be used with %{name}.



%prep
%autosetup -p1 -n %{name}-stable-%{version}



%build
CFLAGS="$(echo %{optflags} -fcommon)" \
%meson --includedir=include/dpdk \
       -Ddrivers_install_subdir=dpdk-pmds \
       -Denable_docs=true \
       -Dmachine=generic \
       --default-library=shared

%meson_build



%install
%meson_install


%pretrans -p <lua>

directories = {
    "/usr/share/dpdk/mk/exec-env/bsdapp",
    "/usr/share/dpdk/mk/exec-env/linuxapp"
}
for i,path in ipairs(directories) do
  st = posix.stat(path)
  if st and st.type == "directory" then
    status = os.rename(path, path .. ".rpmmoved")
    if not status then
      suffix = 0
      while not status do
        suffix = suffix + 1
        status = os.rename(path .. ".rpmmoved", path .. ".rpmmoved." .. suffix)
      end
      os.rename(path, path .. ".rpmmoved")
    end
  end
end

%files
%{_bindir}/dpdk-testpmd
%{_bindir}/dpdk-proc-info
%{_libdir}/*.so.*
%{_libdir}/%{name}-pmds/*.so.*

%files devel
%{_includedir}/%{name}/
%{_datadir}/%{name}
%ghost %{_datadir}/%{name}/mk/exec-env/bsdapp
%ghost %{_datadir}/%{name}/mk/exec-env/linuxapp
%{_libdir}/*.so
%{_libdir}/%{name}-pmds/*.so
%{_libdir}/pkgconfig/libdpdk.pc
%{_libdir}/pkgconfig/libdpdk-libs.pc
%{_docdir}/%{name}
%exclude %{_libdir}/*.a
%exclude %{_bindir}/dpdk-*.py

%files tools
%{_bindir}/dpdk-dumpcap
%{_bindir}/dpdk-pdump
%{_bindir}/dpdk-test
%{_bindir}/dpdk-test-*
%{_bindir}/dpdk-*.py

%changelog
* Mon Mar 24 2025 anatasluo <anatasluo@tencent.com> - 22.11.1-7
- [Type] security
- [DESC] fix CVE-2024-11614

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.11.1-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.11.1-5
- Rebuilt for loongarch release

* Thu May 30 2024 Pengda Dou <doupengda@loongson.cn> - 22.11.1-4
- [Type] other
- [DESC] add loongarch64 to ExclusiveArch

* Wed Jan 17 2024 Rebuild Robot <rebot@opencloudos.org> - 22.11.1-3
- Rebuilt for elfutils

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.11.1-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Jul 13 2023 Shuo Wang <abushwang@tencent.com> - 22.11.1-1
- update to 22.11.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 21.11.2-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 21.11.2-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Nov 29 2022 cunshunxia <cunshunxia@tencent.com> - 21.11.2-1
- initial build
